@@ -205,3 +205,65 @@
 #' head(VR_dilemma)
 #' dplyr::glimpse(VR_dilemma)
 "VR_dilemma"
+
+
+#' @title Tidy version of the "Bugs" dataset.
+#' @name bugs_long
+#' @details This data set, "Bugs", provides the extent to which men and women
+#'   want to kill arthropods that vary in freighteningness (low, high) and
+#'   disgustingness (low, high). Each participant rates their attitudes towards
+#'   all anthropods. Subset of the data reported by Ryan et al. (2013).
+#'
+#' @format A data frame with 372 rows and 6 variables
+#' \itemize{
+#'   \item subject. Dummy identity number for each participant.
+#'   \item gender. Participant's gender (Female, Male).
+#'   \item region. Region of the world the participant was from.
+#'   \item education. Level of education.
+#'   \item condition. Condition of the experiment the participant gave rating
+#'   for (**LDLF**: low freighteningness and low disgustingness; **LFHD**: low
+#'   freighteningness and high disgustingness; **HFHD**: high freighteningness
+#'   and low disgustingness; **HFHD**: high freighteningness and high
+#'   disgustingness).
+#'   \item desire. The desire to kill an arthropod was indicated on a scale from
+#'   0 to 10.
+#' }
+#'
+#' @source
+#' \url{https://www.sciencedirect.com/science/article/pii/S0747563213000277}
+#'
+#' @examples
+#' dim(bugs_long)
+#' head(bugs_long)
+#' dplyr::glimpse(bugs_long)
+"bugs_long"
+
+
+#' @title Wide-format version of the "Bugs" dataset.
+#' @name bugs_wide
+#' @details This data set, "Bugs", provides the extent to which men and women
+#'   want to kill arthropods that vary in freighteningness (low, high) and
+#'   disgustingness (low, high). Each participant rates their attitudes towards
+#'   all anthropods. Subset of the data reported by Ryan et al. (2013).
+#'
+#' @format A data frame with 93 rows and 6 variables
+#' \itemize{
+#'   \item subject. Dummy identity number for each participant.
+#'   \item gender. Participant's gender (Female, Male).
+#'   \item region. Region of the world the participant was from.
+#'   \item education. Level of education.
+#'   \item ldlf,ldhf,hdlf,hdhf.The desire to kill an arthropod was indicated on
+#'   a scale from 0 to 10 in each condition of the experiment (**LDLF**: low
+#'   freighteningness and low disgustingness; **LFHD**: low freighteningness and
+#'   high disgustingness; **HFHD**: high freighteningness and low
+#'   disgustingness; **HFHD**: high freighteningness and high disgustingness).
+#' }
+#'
+#' @source
+#' \url{https://www.sciencedirect.com/science/article/pii/S0747563213000277}
+#'
+#' @examples
+#' dim(bugs_wide)
+#' head(bugs_wide)
+#' dplyr::glimpse(bugs_wide)
+"bugs_wide"
