@@ -3,7 +3,7 @@
 #' @description Helper function for `ggstatsplot::ggdotplotstats` to apply this
 #'   function across multiple levels of a given factor and combining the
 #'   resulting plots using `ggstatsplot::combine_plots`.
-#' @author Indrajeet Patil
+#' @author \href{https://github.com/IndrajeetPatil}{Indrajeet Patil}
 #'
 #' @inheritParams ggdotplotstats
 #' @inheritParams grouped_ggbetweenstats
@@ -12,7 +12,6 @@
 #' @importFrom dplyr select bind_rows summarize mutate mutate_at mutate_if
 #' @importFrom dplyr group_by n arrange
 #' @importFrom rlang !! enquo quo_name ensym
-#' @importFrom glue glue
 #' @importFrom purrr pmap
 #'
 #' @seealso \code{\link{grouped_gghistostats}}, \code{\link{ggdotplotstats}},
@@ -22,7 +21,7 @@
 #' @inherit ggdotplotstats return details
 #'
 #' @examples
-#'
+#' \donttest{
 #' # for reproducibility
 #' set.seed(123)
 #'
@@ -44,6 +43,7 @@
 #'   ),
 #'   messages = FALSE
 #' )
+#' }
 #' @export
 
 # defining the function
@@ -93,38 +93,26 @@ grouped_ggdotplotstats <- function(data,
   # ======================== preparing dataframe ============================
 
   # ensure the grouping variable works quoted or unquoted
+  x <- rlang::ensym(x)
+  y <- rlang::ensym(y)
   grouping.var <- rlang::ensym(grouping.var)
 
   # if `title.prefix` is not provided, use the variable `grouping.var` name
-  if (is.null(title.prefix)) {
-    title.prefix <- rlang::as_name(grouping.var)
-  }
+  if (is.null(title.prefix)) title.prefix <- rlang::as_name(grouping.var)
 
   # creating a dataframe
   df <-
-    data %>%
-    dplyr::select(
-      .data = .,
-      {{ grouping.var }},
-      {{ x }},
-      {{ y }}
-    ) %>%
+    dplyr::select(.data = data, {{ grouping.var }}, {{ x }}, {{ y }}) %>%
     tidyr::drop_na(data = .) %>% # creating a list for grouped analysis
     grouped_list(data = ., grouping.var = {{ grouping.var }})
 
-  # list with basic arguments
-  flexiblelist <- list(
-    data = df,
-    x = rlang::quo_text(rlang::ensym(x)),
-    y = rlang::quo_text(rlang::ensym(y)),
-    title = glue::glue("{title.prefix}: {names(df)}")
-  )
-
   # creating a list of plots
   plotlist_purrr <-
     purrr::pmap(
-      .l = flexiblelist,
+      .l = list(data = df, title = paste(title.prefix, ": ", names(df), sep = "")),
       .f = ggstatsplot::ggdotplotstats,
+      x = {{ x }},
+      y = {{ y }},
       xlab = xlab,
       ylab = ylab,
       stat.title = stat.title,
@@ -164,21 +152,11 @@ grouped_ggdotplotstats <- function(data,
     )
 
   # combining the list of plots into a single plot
+  # inform user this can't be modified further with ggplot commands
   if (return == "plot") {
-    combined_object <-
-      ggstatsplot::combine_plots(
-        plotlist = plotlist_purrr,
-        ...
-      )
-
-    # inform user this can't be modified further with ggplot commands
-    if (isTRUE(messages)) {
-      grouped_message()
-    }
+    if (isTRUE(messages)) grouped_message()
+    return(ggstatsplot::combine_plots(plotlist = plotlist_purrr, ...))
   } else {
-    combined_object <- plotlist_purrr
+    return(plotlist_purrr)
   }
-
-  # return the combined plot
-  return(combined_object)
 }
