@@ -9,10 +9,6 @@ groupedstats::specify_decimal_p
 #' @importFrom groupedstats signif_column
 groupedstats::signif_column
 
-#' @export
-#' @importFrom groupedstats lm_effsize_ci
-groupedstats::lm_effsize_ci
-
 #' @export
 #' @importFrom groupedstats set_cwd
 groupedstats::set_cwd
@@ -23,6 +19,10 @@ groupedstats::set_cwd
 #' @importFrom pairwiseComparisons pairwise_p
 pairwiseComparisons::pairwise_p
 
+#' @export
+#' @importFrom pairwiseComparisons pairwise_comparisons
+pairwiseComparisons::pairwise_comparisons
+
 # ----------------------- tidyverse -------------------------------------
 
 #' @export
