@@ -74,9 +74,9 @@ testthat::test_that(
     testthat::expect_identical(
       pb$data[[4]]$label,
       c(
-        "list(~italic(beta)==6.438, ~italic(t)(28)==13.765, ~italic(p)<= 0.001)",
-        "list(~italic(beta)==-0.156, ~italic(t)(28)==-5.840, ~italic(p)<= 0.001)",
-        "list(~italic(beta)==-1.809, ~italic(t)(28)==-2.615, ~italic(p)== 0.014)",
+        "list(~widehat(italic(beta))==6.438, ~italic(t)(28)==13.765, ~italic(p)<= 0.001)",
+        "list(~widehat(italic(beta))==-0.156, ~italic(t)(28)==-5.840, ~italic(p)<= 0.001)",
+        "list(~widehat(italic(beta))==-1.809, ~italic(t)(28)==-2.615, ~italic(p)== 0.014)",
         NA_character_
       )
     )
@@ -209,9 +209,7 @@ testthat::test_that(
           "AIC = ",
           "43",
           ", BIC = ",
-          "50",
-          ", log-likelihood = ",
-          "-17"
+          "50"
         )
       ))
     )
@@ -226,9 +224,9 @@ testthat::test_that(
     testthat::expect_identical(
       tidy_df$label,
       c(
-        "list(~italic(F)(1*\",\"*28)==118.89, ~italic(p)<= 0.001, ~italic(eta)[p]^2==0.81)",
-        "list(~italic(F)(1*\",\"*28)==7.30, ~italic(p)== 0.012, ~italic(eta)[p]^2==0.21)",
-        "list(~italic(F)(1*\",\"*28)==3.73, ~italic(p)== 0.064, ~italic(eta)[p]^2==0.12)"
+        "list(~italic(F)(1*\",\"*28)==118.89, ~italic(p)<= 0.001, ~widehat(italic(eta)[p]^2)==0.81)",
+        "list(~italic(F)(1*\",\"*28)==7.30, ~italic(p)== 0.012, ~widehat(italic(eta)[p]^2)==0.21)",
+        "list(~italic(F)(1*\",\"*28)==3.73, ~italic(p)== 0.064, ~widehat(italic(eta)[p]^2)==0.12)"
       )
     )
 
@@ -315,9 +313,9 @@ testthat::test_that(
     testthat::expect_identical(
       tidy_df$label,
       c(
-        "list(~italic(F)(3*\",\"*35)==7.388, ~italic(p)== 0.001, ~italic(omega)[p]^2==0.308)",
-        "list(~italic(F)(1*\",\"*35)==2.034, ~italic(p)== 0.163, ~italic(omega)[p]^2==0.023)",
-        "list(~italic(F)(3*\",\"*35)==4.012, ~italic(p)== 0.015, ~italic(omega)[p]^2==0.174)"
+        "list(~italic(F)(3*\",\"*35)==7.388, ~italic(p)== 0.001, ~widehat(italic(omega)[p]^2)==0.308)",
+        "list(~italic(F)(1*\",\"*35)==2.034, ~italic(p)== 0.163, ~widehat(italic(omega)[p]^2)==0.023)",
+        "list(~italic(F)(3*\",\"*35)==4.012, ~italic(p)== 0.015, ~widehat(italic(omega)[p]^2)==0.174)"
       )
     )
     testthat::expect_identical(tidy_df$significance, c("***", "ns", "*"))
@@ -393,18 +391,18 @@ testthat::test_that(
     testthat::expect_identical(
       pb1$data[[4]]$label,
       c(
-        "list(~italic(F)(1*\",\"*35)==3.72, ~italic(p)== 0.062, ~italic(eta)^2==0.05)",
-        "list(~italic(F)(3*\",\"*35)==6.83, ~italic(p)== 0.001, ~italic(eta)^2==0.29)",
-        "list(~italic(F)(3*\",\"*35)==4.01, ~italic(p)== 0.015, ~italic(eta)^2==0.17)"
+        "list(~italic(F)(1*\",\"*35)==3.72, ~italic(p)== 0.062, ~widehat(italic(eta)^2)==0.05)",
+        "list(~italic(F)(3*\",\"*35)==6.83, ~italic(p)== 0.001, ~widehat(italic(eta)^2)==0.29)",
+        "list(~italic(F)(3*\",\"*35)==4.01, ~italic(p)== 0.015, ~widehat(italic(eta)^2)==0.17)"
       )
     )
 
     testthat::expect_identical(
       pb2$data[[4]]$label,
       c(
-        "list(~italic(F)(1*\",\"*35)==3.72, ~italic(p)== 0.062, ~italic(omega)^2==0.04)",
-        "list(~italic(F)(3*\",\"*35)==6.83, ~italic(p)== 0.001, ~italic(omega)^2==0.24)",
-        "list(~italic(F)(3*\",\"*35)==4.01, ~italic(p)== 0.015, ~italic(omega)^2==0.13)"
+        "list(~italic(F)(1*\",\"*35)==3.72, ~italic(p)== 0.062, ~widehat(italic(omega)^2)==0.04)",
+        "list(~italic(F)(3*\",\"*35)==6.83, ~italic(p)== 0.001, ~widehat(italic(omega)^2)==0.24)",
+        "list(~italic(F)(3*\",\"*35)==4.01, ~italic(p)== 0.015, ~widehat(italic(omega)^2)==0.13)"
       )
     )
   }
@@ -587,7 +585,6 @@ testthat::test_that(
 
     # tests
     testthat::expect_equal(dim(df), c(4L, 10L))
-    testthat::expect_identical(as.character(df$term[[1]]), "mpg_(Intercept)")
   }
 )
 
@@ -664,10 +661,10 @@ testthat::test_that(
     testthat::expect_identical(
       pb$data[[4]]$label,
       c(
-        "list(~italic(beta)==3.41, ~italic(t)(169)==6.58, ~italic(p)<= 0.001)",
-        "list(~italic(beta)==-1.25, ~italic(t)(47)==-1.94, ~italic(p)== 0.059)",
-        "list(~italic(beta)==-0.75, ~italic(t)(47)==-1.17, ~italic(p)== 0.248)",
-        "list(~italic(beta)==-1.61, ~italic(t)(169)==-4.49, ~italic(p)<= 0.001)"
+        "list(~widehat(italic(beta))==3.41, ~italic(t)(169)==6.58, ~italic(p)<= 0.001)",
+        "list(~widehat(italic(beta))==-1.25, ~italic(t)(47)==-1.94, ~italic(p)== 0.059)",
+        "list(~widehat(italic(beta))==-0.75, ~italic(t)(47)==-1.17, ~italic(p)== 0.248)",
+        "list(~widehat(italic(beta))==-1.61, ~italic(t)(169)==-4.49, ~italic(p)<= 0.001)"
       )
     )
   }
@@ -856,6 +853,7 @@ testthat::test_that(
       ggplot2::scale_y_discrete(labels = c("x1", "x2", "x3")) +
       ggplot2::labs(x = "location", y = NULL)
     p5 <- ggstatsplot::ggcoefstats(x = df4, statistic = "t")
+    set.seed(123)
     p6 <-
       suppressWarnings(ggstatsplot::ggcoefstats(
         x = df5,
@@ -863,19 +861,19 @@ testthat::test_that(
         k = 3,
         meta.analytic.effect = TRUE,
         bf.message = TRUE,
-        iter = 2500,
-        summarize = "int",
         messages = FALSE
       ))
-
-    # meta subtitle
-    meta_subtitle <-
-      ggstatsplot::subtitle_meta_ggcoefstats(
-        data = df5,
+    p7 <-
+      suppressWarnings(ggstatsplot::ggcoefstats(
+        x = df5,
+        statistic = "t",
         k = 3,
-        messages = FALSE,
-        output = "subtitle"
-      )
+        meta.analytic.effect = TRUE,
+        meta.type = "bf",
+        caption = "mnp",
+        bf.message = TRUE,
+        messages = FALSE
+      ))
 
     # build plots
     pb1 <- ggplot2::ggplot_build(p1)
@@ -884,22 +882,23 @@ testthat::test_that(
     pb4 <- ggplot2::ggplot_build(p4)
     pb5 <- ggplot2::ggplot_build(p5)
     pb6 <- ggplot2::ggplot_build(p6)
+    pb7 <- ggplot2::ggplot_build(p7)
 
     # stats labels
     testthat::expect_identical(
       pb1$data[[4]]$label,
       c(
-        "list(~italic(beta)==0.07, ~italic(t)(5)==0.16, ~italic(p)== 0.875)",
-        "list(~italic(beta)==0.54, ~italic(t)(10)==1.33, ~italic(p)== 0.191)",
-        "list(~italic(beta)==0.04, ~italic(t)(12)==1.24, ~italic(p)== 0.001)"
+        "list(~widehat(italic(beta))==0.07, ~italic(t)(5)==0.16, ~italic(p)== 0.875)",
+        "list(~widehat(italic(beta))==0.54, ~italic(t)(10)==1.33, ~italic(p)== 0.191)",
+        "list(~widehat(italic(beta))==0.04, ~italic(t)(12)==1.24, ~italic(p)== 0.001)"
       )
     )
     testthat::expect_identical(
       pb5$data[[4]]$label,
       c(
-        "list(~italic(beta)==0.07, ~italic(t)==0.16, ~italic(p)== 0.875)",
-        "list(~italic(beta)==0.54, ~italic(t)==1.33, ~italic(p)== 0.191)",
-        "list(~italic(beta)==0.04, ~italic(t)==1.24, ~italic(p)== 0.001)"
+        "list(~widehat(italic(beta))==0.07, ~italic(t)==0.16, ~italic(p)== 0.875)",
+        "list(~widehat(italic(beta))==0.54, ~italic(t)==1.33, ~italic(p)== 0.191)",
+        "list(~widehat(italic(beta))==0.04, ~italic(t)==1.24, ~italic(p)== 0.001)"
       )
     )
 
@@ -907,9 +906,9 @@ testthat::test_that(
     testthat::expect_identical(
       pb2$data[[4]]$label,
       c(
-        "list(~italic(beta)==0.07, ~italic(z)==0.16, ~italic(p)== 0.875)",
-        "list(~italic(beta)==0.54, ~italic(z)==1.33, ~italic(p)== 0.191)",
-        "list(~italic(beta)==0.04, ~italic(z)==1.24, ~italic(p)== 0.001)"
+        "list(~widehat(italic(beta))==0.07, ~italic(z)==0.16, ~italic(p)== 0.875)",
+        "list(~widehat(italic(beta))==0.54, ~italic(z)==1.33, ~italic(p)== 0.191)",
+        "list(~widehat(italic(beta))==0.04, ~italic(z)==1.24, ~italic(p)== 0.001)"
       )
     )
 
@@ -954,52 +953,25 @@ testthat::test_that(
       meta.analytic.effect = TRUE
     ))
 
-    testthat::expect_identical(pb6$plot$labels$subtitle, meta_subtitle)
+    # subtitle
+    set.seed(123)
+    meta_info <- suppressWarnings(capture.output(ggstatsplot::ggcoefstats(
+      x = df5,
+      statistic = "t",
+      k = 3,
+      meta.analytic.effect = TRUE,
+      bf.message = TRUE,
+      messages = TRUE
+    )))
+
+    # tests
+    testthat::expect_identical(meta_info[13], "Q(df = 2) = 5.6910, p-val = 0.0581")
+    testthat::expect_identical(meta_info[30], "  random_H0     1.000      1.31")
     testthat::expect_identical(
-      pb6$plot$labels$caption,
-      ggplot2::expr(atop(
-        displaystyle(atop(
-          displaystyle(NULL),
-          expr = paste(
-            "In favor of null: ",
-            "log"["e"],
-            "(BF"["01"],
-            ") = ",
-            "0.174",
-            ", ",
-            italic("d")["mean"]^"posterior",
-            " = ",
-            "0.110",
-            ", CI"["95%"],
-            " [",
-            "-0.178",
-            ", ",
-            "0.412",
-            "]"
-          )
-        )),
-        expr = paste(
-          "Heterogeneity: ",
-          italic("Q"),
-          "(",
-          "2",
-          ") = ",
-          "6",
-          ", ",
-          italic("p"),
-          " = ",
-          "0.058",
-          ", ",
-          tau["REML"]^2,
-          " = ",
-          "0.030",
-          ", ",
-          "I"^2,
-          " = ",
-          "81.42%"
-        )
-      ))
+      meta_info[18],
+      "  0.1515  0.1171  1.2938  0.1957  -0.0780  0.3811    "
     )
+    testthat::expect_identical(pb7$plot$labels$caption, "mnp")
   }
 )
 
@@ -1039,8 +1011,8 @@ testthat::test_that(
     testthat::expect_identical(
       pb$data[[4]]$label,
       c(
-        "list(~italic(beta)==0.07, ~italic(t)==0.16, ~italic(p)== 0.875)",
-        "list(~italic(beta)==0.04, ~italic(t)==1.24, ~italic(p)== 0.001)"
+        "list(~widehat(italic(beta))==0.07, ~italic(t)==0.16, ~italic(p)== 0.875)",
+        "list(~widehat(italic(beta))==0.04, ~italic(t)==1.24, ~italic(p)== 0.001)"
       )
     )
   }
@@ -1142,8 +1114,8 @@ testthat::test_that(
     testthat::expect_identical(
       tidy_df2$label,
       c(
-        "list(~italic(beta)==251.41, ~italic(t)(174)==36.84, ~italic(p)<= 0.001)",
-        "list(~italic(beta)==10.47, ~italic(t)(174)==6.77, ~italic(p)<= 0.001)"
+        "list(~widehat(italic(beta))==251.41, ~italic(t)(174)==36.84, ~italic(p)<= 0.001)",
+        "list(~widehat(italic(beta))==10.47, ~italic(t)(174)==6.77, ~italic(p)<= 0.001)"
       )
     )
   }
@@ -1205,44 +1177,15 @@ testthat::test_that(
     testthat::expect_true(inherits(df3.ggstats, what = "tbl_df"))
 
     # wait for parameters' new version to make it to CRAN
-    # testthat::expect_identical(
-    #   df2.tidy$label,
-    #   c(
-    #     "list(~italic(beta)==-40.47, ~italic(t)==-3.40, ~italic(p)== 0.001)",
-    #     "list(~italic(beta)==0.74, ~italic(t)==5.50, ~italic(p)<= 0.001)",
-    #     "list(~italic(beta)==1.23, ~italic(t)==3.33, ~italic(p)== 0.001)",
-    #     "list(~italic(beta)==-0.15, ~italic(t)==-0.93, ~italic(p)== 0.352)"
-    #   )
-    # )
-  }
-)
-
-# augment with lm works ----------------------------------------
-
-testthat::test_that(
-  desc = "augment with lm works",
-  code = {
-    testthat::skip_on_cran()
-    testthat::skip_on_appveyor()
-    testthat::skip_on_travis()
-
-    # augment
-    set.seed(123)
-    mod4 <- stats::lm(formula = mpg ~ wt + qsec, data = mtcars)
-    newdata <- mtcars %>%
-      head(6) %>%
-      dplyr::mutate(.data = ., wt = wt + 1)
-    df4.broom <- tibble::as_tibble(broom::augment(x = mod4, newdata = newdata))
-    df4.ggstats <-
-      ggstatsplot::ggcoefstats(
-        x = mod4,
-        output = "augment",
-        newdata = newdata
+    testthat::expect_identical(
+      df2.tidy$label,
+      c(
+        "list(~widehat(italic(beta))==-40.47, ~italic(t)==-3.40, ~italic(p)== 0.003)",
+        "list(~widehat(italic(beta))==0.74, ~italic(t)==5.50, ~italic(p)<= 0.001)",
+        "list(~widehat(italic(beta))==1.23, ~italic(t)==3.33, ~italic(p)== 0.004)",
+        "list(~widehat(italic(beta))==-0.15, ~italic(t)==-0.93, ~italic(p)== 0.365)"
       )
-
-    # tests
-    testthat::expect_identical(df4.broom, df4.ggstats)
-    testthat::expect_equal(dim(df4.ggstats), c(6L, 13L))
+    )
   }
 )
 
@@ -1383,11 +1326,11 @@ testthat::test_that(
     testthat::expect_equal(
       df$label,
       c(
-        "list(~italic(beta)==3.04, ~italic(z)==17.81, ~italic(p)<= 0.001)",
-        "list(~italic(beta)==-0.45, ~italic(z)==-2.25, ~italic(p)== 0.025)",
-        "list(~italic(beta)==-0.29, ~italic(z)==-1.52, ~italic(p)== 0.128)",
-        "list(~italic(beta)==0.00, ~italic(z)==0.00, ~italic(p)== 1.000)",
-        "list(~italic(beta)==0.00, ~italic(z)==0.00, ~italic(p)== 1.000)"
+        "list(~widehat(italic(beta))==3.04, ~italic(z)==17.81, ~italic(p)<= 0.001)",
+        "list(~widehat(italic(beta))==-0.45, ~italic(z)==-2.25, ~italic(p)== 0.025)",
+        "list(~widehat(italic(beta))==-0.29, ~italic(z)==-1.52, ~italic(p)== 0.128)",
+        "list(~widehat(italic(beta))==0.00, ~italic(z)==0.00, ~italic(p)== 1.000)",
+        "list(~widehat(italic(beta))==0.00, ~italic(z)==0.00, ~italic(p)== 1.000)"
       )
     )
   }
@@ -1462,8 +1405,67 @@ testthat::test_that(
     testthat::expect_equal(
       df$label,
       c(
-        "list(~italic(beta)==0.02, ~italic(t)(68)==41.12, ~italic(p)<= 0.001)",
-        "list(~italic(beta)==0.00, ~italic(t)(68)==-7.27, ~italic(p)<= 0.001)"
+        "list(~widehat(italic(beta))==0.02, ~italic(t)(68)==41.12, ~italic(p)<= 0.001)",
+        "list(~widehat(italic(beta))==0.00, ~italic(t)(68)==-7.27, ~italic(p)<= 0.001)"
+      )
+    )
+  }
+)
+
+# `easystats` works -------------------------------------------------------
+
+testthat::test_that(
+  desc = "easystats works",
+  code = {
+    testthat::skip_on_cran()
+
+
+    set.seed(123)
+    library(mixor)
+    data("SmokingPrevention")
+
+    # data frame must be sorted by id variable
+    SmokingPrevention <- SmokingPrevention[order(SmokingPrevention$class), ]
+
+    # school model
+    suppressMessages(suppressWarnings(mod <-
+      mixor::mixor(
+        thksord ~ thkspre + cc + tv + cctv,
+        data = SmokingPrevention,
+        id = school,
+        link = "logit"
+      )))
+
+    # plot
+    p <- ggstatsplot::ggcoefstats(
+      x = mod,
+      title = "Mixed-Effects Ordinal Regression Analysis",
+      exclude.intercept = FALSE
+    )
+
+    # build the plot
+    pb <- ggplot2::ggplot_build(p)
+
+    # testing captions and labels
+    testthat::expect_identical(
+      pb$plot$labels$caption,
+      ggplot2::expr(atop(displaystyle(NULL), expr = paste(
+        "AIC = ", "-2128",
+        ", BIC = ", "-2133"
+      )))
+    )
+
+    testthat::expect_equal(
+      pb$data[[4]]$label,
+      c(
+        "list(~widehat(italic(beta))==0.09, ~italic(z)==0.28, ~italic(p)== 0.778)",
+        "list(~widehat(italic(beta))==1.24, ~italic(z)==14.06, ~italic(p)<= 0.001)",
+        "list(~widehat(italic(beta))==2.42, ~italic(z)==28.95, ~italic(p)<= 0.001)",
+        "list(~widehat(italic(beta))==0.40, ~italic(z)==9.39, ~italic(p)<= 0.001)",
+        "list(~widehat(italic(beta))==0.92, ~italic(z)==2.49, ~italic(p)== 0.013)",
+        "list(~widehat(italic(beta))==0.28, ~italic(z)==0.87, ~italic(p)== 0.383)",
+        "list(~widehat(italic(beta))==-0.47, ~italic(z)==-1.15, ~italic(p)== 0.251)",
+        "list(~widehat(italic(beta))==0.07, ~italic(z)==1.49, ~italic(p)== 0.137)"
       )
     )
   }
