@@ -593,7 +593,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          italic("r"),
+          widehat(italic("r")),
           " = ",
           "-0.58",
           ", CI"["95%"],
