@@ -204,7 +204,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          widehat(italic("r")["Pearson"]),
+          widehat(italic("r"))["Pearson"],
           " = ",
           "0.599",
           ", CI"["99%"],
@@ -235,7 +235,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          widehat(italic("r")["Pearson"]),
+          widehat(italic("r"))["Pearson"],
           " = ",
           "0.364",
           ", CI"["99%"],
@@ -266,7 +266,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          widehat(italic("r")["Pearson"]),
+          widehat(italic("r"))["Pearson"],
           " = ",
           "0.548",
           ", CI"["99%"],
@@ -297,7 +297,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          widehat(italic("r")["Pearson"]),
+          widehat(italic("r"))["Pearson"],
           " = ",
           "0.308",
           ", CI"["99%"],
